==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/powerbidedicated/kotlin/inputs/SystemDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.powerbidedicated.kotlin.inputs

import com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs.builder
import com.pulumi.azurenative.powerbidedicated.kotlin.enums.IdentityType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Metadata pertaining to creation and last modification of the resource.
 * @property createdAt The timestamp of resource creation (UTC)
 * @property createdBy An identifier for the identity that created the resource
 * @property createdByType The type of identity that created the resource
 * @property lastModifiedAt The timestamp of resource last modification (UTC)
 * @property lastModifiedBy An identifier for the identity that last modified the resource
 * @property lastModifiedByType The type of identity that last modified the resource
 */
public data class SystemDataArgs(
    public val createdAt: Output<String>? = null,
    public val createdBy: Output<String>? = null,
    public val createdByType: Output<Either<String, IdentityType>>? = null,
    public val lastModifiedAt: Output<String>? = null,
    public val lastModifiedBy: Output<String>? = null,
    public val lastModifiedByType: Output<Either<String, IdentityType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs> {
    override fun toJava(): com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs =
        com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs.builder()
            .createdAt(createdAt?.applyValue({ args0 -> args0 }))
            .createdBy(createdBy?.applyValue({ args0 -> args0 }))
            .createdByType(
                createdByType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .lastModifiedAt(lastModifiedAt?.applyValue({ args0 -> args0 }))
            .lastModifiedBy(lastModifiedBy?.applyValue({ args0 -> args0 }))
            .lastModifiedByType(
                lastModifiedByType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [SystemDataArgs].
 */
@PulumiTagMarker
public class SystemDataArgsBuilder internal constructor() {
    private var createdAt: Output<String>? = null

    private var createdBy: Output<String>? = null

    private var createdByType: Output<Either<String, IdentityType>>? = null

    private var lastModifiedAt: Output<String>? = null

    private var lastModifiedBy: Output<String>? = null

    private var lastModifiedByType: Output<Either<String, IdentityType>>? = null

    /**
     * @param value The timestamp of resource creation (UTC)
     */
    @JvmName("nnrannnunlxuwexq")
    public suspend fun createdAt(`value`: Output<String>) {
        this.createdAt = value
    }

    /**
     * @param value An identifier for the identity that created the resource
     */
    @JvmName("lvhmwptaxdcfshvd")
    public suspend fun createdBy(`value`: Output<String>) {
        this.createdBy = value
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("nxbbijhbwsrvkibg")
    public suspend fun createdByType(`value`: Output<Either<String, IdentityType>>) {
        this.createdByType = value
    }

    /**
     * @param value The timestamp of resource last modification (UTC)
     */
    @JvmName("ujihbejudwfvaefb")
    public suspend fun lastModifiedAt(`value`: Output<String>) {
        this.lastModifiedAt = value
    }

    /**
     * @param value An identifier for the identity that last modified the resource
     */
    @JvmName("xbcmkkhdkaurqeeg")
    public suspend fun lastModifiedBy(`value`: Output<String>) {
        this.lastModifiedBy = value
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("qeqwmstboqtocxsp")
    public suspend fun lastModifiedByType(`value`: Output<Either<String, IdentityType>>) {
        this.lastModifiedByType = value
    }

    /**
     * @param value The timestamp of resource creation (UTC)
     */
    @JvmName("hbpprmrtgysmvjuv")
    public suspend fun createdAt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdAt = mapped
    }

    /**
     * @param value An identifier for the identity that created the resource
     */
    @JvmName("ontynmncrkjvtmbi")
    public suspend fun createdBy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdBy = mapped
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("pbioujsteufhwgos")
    public suspend fun createdByType(`value`: Either<String, IdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdByType = mapped
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("xqcfyqgalgirnsli")
    public fun createdByType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.createdByType = mapped
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("pggsjdlapaiguvon")
    public fun createdByType(`value`: IdentityType) {
        val toBeMapped = Either.ofRight<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.createdByType = mapped
    }

    /**
     * @param value The timestamp of resource last modification (UTC)
     */
    @JvmName("fdmyyliueososepb")
    public suspend fun lastModifiedAt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastModifiedAt = mapped
    }

    /**
     * @param value An identifier for the identity that last modified the resource
     */
    @JvmName("lbmoqeewxfbcutnv")
    public suspend fun lastModifiedBy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastModifiedBy = mapped
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("gxpwqrssqtnsqvbl")
    public suspend fun lastModifiedByType(`value`: Either<String, IdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastModifiedByType = mapped
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("rwwxjscbaoovprsr")
    public fun lastModifiedByType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lastModifiedByType = mapped
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("tsidoogvnstrueoh")
    public fun lastModifiedByType(`value`: IdentityType) {
        val toBeMapped = Either.ofRight<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lastModifiedByType = mapped
    }

    internal fun build(): SystemDataArgs = SystemDataArgs(
        createdAt = createdAt,
        createdBy = createdBy,
        createdByType = createdByType,
        lastModifiedAt = lastModifiedAt,
        lastModifiedBy = lastModifiedBy,
        lastModifiedByType = lastModifiedByType,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/powerbidedicated/kotlin/inputs/SystemDataArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.powerbidedicated.kotlin.inputs

import com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs.builder
import com.pulumi.azurenative.powerbidedicated.kotlin.enums.IdentityType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Metadata pertaining to creation and last modification of the resource.
 * @property createdAt The timestamp of resource creation (UTC)
 * @property createdBy An identifier for the identity that created the resource
 * @property createdByType The type of identity that created the resource
 * @property lastModifiedAt The timestamp of resource last modification (UTC)
 * @property lastModifiedBy An identifier for the identity that last modified the resource
 * @property lastModifiedByType The type of identity that last modified the resource
 */
public data class SystemDataArgs(
    public val createdAt: Output<String>? = null,
    public val createdBy: Output<String>? = null,
    public val createdByType: Output<Either<String, IdentityType>>? = null,
    public val lastModifiedAt: Output<String>? = null,
    public val lastModifiedBy: Output<String>? = null,
    public val lastModifiedByType: Output<Either<String, IdentityType>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs> {
    override fun toJava(): com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs =
        com.pulumi.azurenative.powerbidedicated.inputs.SystemDataArgs.builder()
            .createdAt(createdAt?.applyValue({ args0 -> args0 }))
            .createdBy(createdBy?.applyValue({ args0 -> args0 }))
            .createdByType(
                createdByType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .lastModifiedAt(lastModifiedAt?.applyValue({ args0 -> args0 }))
            .lastModifiedBy(lastModifiedBy?.applyValue({ args0 -> args0 }))
            .lastModifiedByType(
                lastModifiedByType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            ).build()
}

/**
 * Builder for [SystemDataArgs].
 */
@PulumiTagMarker
public class SystemDataArgsBuilder internal constructor() {
    private var createdAt: Output<String>? = null

    private var createdBy: Output<String>? = null

    private var createdByType: Output<Either<String, IdentityType>>? = null

    private var lastModifiedAt: Output<String>? = null

    private var lastModifiedBy: Output<String>? = null

    private var lastModifiedByType: Output<Either<String, IdentityType>>? = null

    /**
     * @param value The timestamp of resource creation (UTC)
     */
    @JvmName("gmlmvipbqsyfumhj")
    public suspend fun createdAt(`value`: Output<String>) {
        this.createdAt = value
    }

    /**
     * @param value An identifier for the identity that created the resource
     */
    @JvmName("dpvfetggufwnpdes")
    public suspend fun createdBy(`value`: Output<String>) {
        this.createdBy = value
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("lplhcjovsihkshag")
    public suspend fun createdByType(`value`: Output<Either<String, IdentityType>>) {
        this.createdByType = value
    }

    /**
     * @param value The timestamp of resource last modification (UTC)
     */
    @JvmName("bajpjktxpohcbcyq")
    public suspend fun lastModifiedAt(`value`: Output<String>) {
        this.lastModifiedAt = value
    }

    /**
     * @param value An identifier for the identity that last modified the resource
     */
    @JvmName("pmbopsrqhwgdtppg")
    public suspend fun lastModifiedBy(`value`: Output<String>) {
        this.lastModifiedBy = value
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("yqkfdjvqehlqrqql")
    public suspend fun lastModifiedByType(`value`: Output<Either<String, IdentityType>>) {
        this.lastModifiedByType = value
    }

    /**
     * @param value The timestamp of resource creation (UTC)
     */
    @JvmName("mgcjktsjnybkkamk")
    public suspend fun createdAt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdAt = mapped
    }

    /**
     * @param value An identifier for the identity that created the resource
     */
    @JvmName("qyqyixacnuamswsl")
    public suspend fun createdBy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdBy = mapped
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("awulilsdrmpkkrmw")
    public suspend fun createdByType(`value`: Either<String, IdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.createdByType = mapped
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("xgwgkpmoimbcgkkr")
    public fun createdByType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.createdByType = mapped
    }

    /**
     * @param value The type of identity that created the resource
     */
    @JvmName("ykncqpnsdkmsucil")
    public fun createdByType(`value`: IdentityType) {
        val toBeMapped = Either.ofRight<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.createdByType = mapped
    }

    /**
     * @param value The timestamp of resource last modification (UTC)
     */
    @JvmName("vxheohcutojbyxwn")
    public suspend fun lastModifiedAt(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastModifiedAt = mapped
    }

    /**
     * @param value An identifier for the identity that last modified the resource
     */
    @JvmName("vkgqumvxcgtfbyle")
    public suspend fun lastModifiedBy(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastModifiedBy = mapped
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("tbycfnhocmsfhpvq")
    public suspend fun lastModifiedByType(`value`: Either<String, IdentityType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.lastModifiedByType = mapped
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("iinxiyepcxebqtdr")
    public fun lastModifiedByType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lastModifiedByType = mapped
    }

    /**
     * @param value The type of identity that last modified the resource
     */
    @JvmName("joeanjlkouxtawnn")
    public fun lastModifiedByType(`value`: IdentityType) {
        val toBeMapped = Either.ofRight<String, IdentityType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.lastModifiedByType = mapped
    }

    internal fun build(): SystemDataArgs = SystemDataArgs(
        createdAt = createdAt,
        createdBy = createdBy,
        createdByType = createdByType,
        lastModifiedAt = lastModifiedAt,
        lastModifiedBy = lastModifiedBy,
        lastModifiedByType = lastModifiedByType,
    )
}
